@@ -415,8 +415,8 @@ class PysonConnect:
                 "Content-Type":"application/json"
                 }
         data = {
-                "alias_name":data["AliasName"],
-                "type":data["destType"],
+                "alias_name":data["alias_name"],
+                "type":data["dest_type"],
                 "destination":data["destination"]
                 }
         r = requests.post(url=req_uri, headers=headers, data=json.dumps(data))
@@ -428,7 +428,7 @@ class PysonConnect:
             self.err.errors(message=message)
 
 
-    def updateScanDestination(self, data, access_token=None, subject_id=None):
+    def update_scan_destination(self, data, access_token=None, subject_id=None):
         if access_token == None:
             access_token = self.access_token
 
@@ -441,9 +441,9 @@ class PysonConnect:
                 "Content-Type":"application/json"
                 }
         data = {
-                "id":data["scanDestID"],
-                "alias_name":data["AliasName"],
-                "type":data["destType"],
+                "id":data["scan_dest_id"],
+                "alias_name":data["alias_name"],
+                "type":data["dest_type"],
                 "destination":data["destination"]
                 }
         r = requests.put(url=req_uri, headers=headers, data=json.dumps(data))
@@ -455,14 +455,14 @@ class PysonConnect:
             self.err.errors(message=message)
 
     
-    def deleteScanDestination(self, access_token, subject_id, scanDestID):
+    def delete_scan_destination(self, access_token, subject_id, scan_dest_id):
         req_uri = f"{self.base_uri}/api/1/scanning/scanners/{subject_id}/destinations"
         headers = {
                 "Authorization":f"Bearer {access_token}",
                 "Content-Type":"application/json"
                 }
         data = {
-                "id":scanDestID
+                "id":scan_dest_id
                 }
         r = requests.delete(url=req_uri, headers=headers, data=json.dumps(data))
         rjson = r.json()
